"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Input = void 0;
const react_1 = __importDefault(require("react"));
const colors_1 = require("../../constants/colors");
const defaultLayouts_1 = require("../../constants/defaultLayouts");
const stringGenerator_1 = require("../../helpers/stringGenerator");
const alignTypes_1 = require("../../types/alignTypes");
const cursorTypes_1 = require("../../types/cursorTypes");
const CheckboxInput_1 = require("./inputs/CheckboxInput");
const EmailInput_1 = require("./inputs/EmailInput");
const HiddenInput_1 = require("./inputs/HiddenInput");
const NumberInput_1 = require("./inputs/NumberInput");
const PasswordInput_1 = require("./inputs/PasswordInput");
const RadioInput_1 = require("./inputs/RadioInput");
const TextInput_1 = require("./inputs/TextInput");
const styles_1 = require("./styles");
const inputTypes_1 = require("./types/inputTypes");
const Input = ({ className, id, name, type = inputTypes_1.InputTypes.TEXT, labelText, placeholder, icon, iconSize = defaultLayouts_1.DEFAULT_INPUT_ICON_SIZE, withShowHide = false, value, backgroundColor = colors_1.DEFAULT_BACKGROUND, textColor = colors_1.DEFAULT_PRIMARY, labelBackgroundColor = colors_1.DEFAULT_BACKGROUND, labelTextColor = colors_1.DEFAULT_PRIMARY, containerPadding = defaultLayouts_1.DEFAULT_PADDING, containerMargin = defaultLayouts_1.DEFAULT_MARGIN, padding = defaultLayouts_1.DEFAULT_PADDING, margin = defaultLayouts_1.DEFAULT_MARGIN, width = defaultLayouts_1.DEFAULT_WIDTH, height = defaultLayouts_1.DEFAULT_HEIGHT, outline, border, borderRadius, cursor = cursorTypes_1.CursorType.DEFAULT, required = false, min, max, autoFocus = false, checked = false, disabled = false, maxLength, minLength, pattern, step, error = "", errorBackgroundColor = colors_1.DEFAULT_BACKGROUND, errorTextColor = colors_1.DEFAULT_ERROR, alignItem = alignTypes_1.AlignTypes.LEFT, onChange, onFocus, onBlur, }) => {
    let inputField;
    const inputId = id ? id : `input_${(0, stringGenerator_1.generateRandomString)()}`;
    switch (type) {
        case inputTypes_1.InputTypes.TEXT:
            inputField = (react_1.default.createElement(TextInput_1.TextInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, icon: icon, iconSize: iconSize, maxLength: maxLength, minLength: minLength, pattern: pattern }));
            break;
        case inputTypes_1.InputTypes.NUMBER:
            inputField = (react_1.default.createElement(NumberInput_1.NumberInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, icon: icon, iconSize: iconSize, min: min, max: max, step: step }));
            break;
        case inputTypes_1.InputTypes.PASSWORD:
            inputField = (react_1.default.createElement(PasswordInput_1.PasswordInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, icon: icon, iconSize: iconSize, withShowHide: withShowHide, maxLength: maxLength, minLength: minLength, pattern: pattern }));
            break;
        case inputTypes_1.InputTypes.CHECKBOX:
            inputField = (react_1.default.createElement(CheckboxInput_1.CheckboxInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, icon: icon, iconSize: iconSize, checked: checked }));
            break;
        case inputTypes_1.InputTypes.EMAIL:
            inputField = (react_1.default.createElement(EmailInput_1.EmailInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, icon: icon, iconSize: iconSize, maxLength: maxLength, minLength: minLength, pattern: pattern }));
            break;
        case inputTypes_1.InputTypes.HIDDEN:
            inputField = (react_1.default.createElement(HiddenInput_1.HiddenInput, { className: className, name: name, id: inputId, type: type, value: value, disabled: disabled, onFocus: onFocus, onBlur: onBlur }));
            break;
        case inputTypes_1.InputTypes.RADIO:
            inputField = (react_1.default.createElement(RadioInput_1.RadioInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, checked: checked }));
            break;
        default:
            inputField = (react_1.default.createElement(TextInput_1.TextInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, icon: icon, iconSize: iconSize, maxLength: maxLength, minLength: minLength, pattern: pattern }));
            break;
    }
    return (react_1.default.createElement(styles_1.Container, { backgroundColor: backgroundColor, textColor: textColor, padding: containerPadding, margin: containerMargin, width: width, height: height, outline: outline, border: border, borderRadius: borderRadius, cursor: cursor, alignItem: alignItem },
        [
            inputTypes_1.InputTypes.TEXT,
            inputTypes_1.InputTypes.PASSWORD,
            inputTypes_1.InputTypes.EMAIL,
            inputTypes_1.InputTypes.NUMBER,
        ].includes(type) && (react_1.default.createElement(styles_1.Label, { backgroundColor: labelBackgroundColor, textColor: labelTextColor, for: inputId }, labelText)),
        react_1.default.createElement(styles_1.InputWrapper, null,
            inputField,
            [inputTypes_1.InputTypes.CHECKBOX, inputTypes_1.InputTypes.RADIO].includes(type) && (react_1.default.createElement(styles_1.Label, { for: inputId }, labelText))),
        error &&
            [
                inputTypes_1.InputTypes.TEXT,
                inputTypes_1.InputTypes.PASSWORD,
                inputTypes_1.InputTypes.EMAIL,
                inputTypes_1.InputTypes.NUMBER,
            ].includes(type) && (react_1.default.createElement(styles_1.Error, { backgroundColor: errorBackgroundColor, textColor: errorTextColor }, error))));
};
exports.Input = Input;
//# sourceMappingURL=Input.js.map