import React from "react";
import { DEFAULT_BACKGROUND, DEFAULT_ERROR, DEFAULT_PRIMARY, } from "../../constants/colors";
import { DEFAULT_HEIGHT, DEFAULT_INPUT_ICON_SIZE, DEFAULT_MARGIN, DEFAULT_PADDING, DEFAULT_WIDTH, } from "../../constants/defaultLayouts";
import { generateRandomString } from "../../helpers/stringGenerator";
import { AlignTypes } from "../../types/alignTypes";
import { CursorType } from "../../types/cursorTypes";
import { CheckboxInput } from "./inputs/CheckboxInput";
import { EmailInput } from "./inputs/EmailInput";
import { HiddenInput } from "./inputs/HiddenInput";
import { NumberInput } from "./inputs/NumberInput";
import { PasswordInput } from "./inputs/PasswordInput";
import { RadioInput } from "./inputs/RadioInput";
import { TextInput } from "./inputs/TextInput";
import { Container, Error, InputWrapper, Label } from "./styles";
import { InputTypes } from "./types/inputTypes";
export const Input = ({ className, id, name, type = InputTypes.TEXT, labelText, placeholder, icon, iconSize = DEFAULT_INPUT_ICON_SIZE, withShowHide = false, value, backgroundColor = DEFAULT_BACKGROUND, textColor = DEFAULT_PRIMARY, labelBackgroundColor = DEFAULT_BACKGROUND, labelTextColor = DEFAULT_PRIMARY, containerPadding = DEFAULT_PADDING, containerMargin = DEFAULT_MARGIN, padding = DEFAULT_PADDING, margin = DEFAULT_MARGIN, width = DEFAULT_WIDTH, height = DEFAULT_HEIGHT, outline, border, borderRadius, cursor = CursorType.DEFAULT, required = false, min, max, autoFocus = false, checked = false, disabled = false, maxLength, minLength, pattern, step, error = "", errorBackgroundColor = DEFAULT_BACKGROUND, errorTextColor = DEFAULT_ERROR, alignItem = AlignTypes.LEFT, onChange, onFocus, onBlur, }) => {
    let inputField;
    const inputId = id ? id : `input_${generateRandomString()}`;
    switch (type) {
        case InputTypes.TEXT:
            inputField = (React.createElement(TextInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, icon: icon, iconSize: iconSize, maxLength: maxLength, minLength: minLength, pattern: pattern }));
            break;
        case InputTypes.NUMBER:
            inputField = (React.createElement(NumberInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, icon: icon, iconSize: iconSize, min: min, max: max, step: step }));
            break;
        case InputTypes.PASSWORD:
            inputField = (React.createElement(PasswordInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, icon: icon, iconSize: iconSize, withShowHide: withShowHide, maxLength: maxLength, minLength: minLength, pattern: pattern }));
            break;
        case InputTypes.CHECKBOX:
            inputField = (React.createElement(CheckboxInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, icon: icon, iconSize: iconSize, checked: checked }));
            break;
        case InputTypes.EMAIL:
            inputField = (React.createElement(EmailInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, icon: icon, iconSize: iconSize, maxLength: maxLength, minLength: minLength, pattern: pattern }));
            break;
        case InputTypes.HIDDEN:
            inputField = (React.createElement(HiddenInput, { className: className, name: name, id: inputId, type: type, value: value, disabled: disabled, onFocus: onFocus, onBlur: onBlur }));
            break;
        case InputTypes.RADIO:
            inputField = (React.createElement(RadioInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, checked: checked }));
            break;
        default:
            inputField = (React.createElement(TextInput, { className: className, name: name, id: inputId, type: type, value: value, padding: padding, margin: margin, required: required, 
                // eslint-disable-next-line jsx-a11y/no-autofocus
                autoFocus: autoFocus, disabled: disabled, onChange: onChange, onFocus: onFocus, onBlur: onBlur, placeholder: placeholder, icon: icon, iconSize: iconSize, maxLength: maxLength, minLength: minLength, pattern: pattern }));
            break;
    }
    return (React.createElement(Container, { backgroundColor: backgroundColor, textColor: textColor, padding: containerPadding, margin: containerMargin, width: width, height: height, outline: outline, border: border, borderRadius: borderRadius, cursor: cursor, alignItem: alignItem },
        [
            InputTypes.TEXT,
            InputTypes.PASSWORD,
            InputTypes.EMAIL,
            InputTypes.NUMBER,
        ].includes(type) && (React.createElement(Label, { backgroundColor: labelBackgroundColor, textColor: labelTextColor, for: inputId }, labelText)),
        React.createElement(InputWrapper, null,
            inputField,
            [InputTypes.CHECKBOX, InputTypes.RADIO].includes(type) && (React.createElement(Label, { for: inputId }, labelText))),
        error &&
            [
                InputTypes.TEXT,
                InputTypes.PASSWORD,
                InputTypes.EMAIL,
                InputTypes.NUMBER,
            ].includes(type) && (React.createElement(Error, { backgroundColor: errorBackgroundColor, textColor: errorTextColor }, error))));
};
//# sourceMappingURL=Input.js.map