import styled from "styled-components";
import { DEFAULT_PRIMARY } from "../../constants/colors";
import { AlignTypes } from "../../types/alignTypes";
import { InputTypes } from "./types/inputTypes";
export const Container = styled.div `
  display: flex;
  flex-direction: column;
  justify-content: center;

  align-items: ${({ alignItem }) => {
    switch (alignItem) {
        case AlignTypes.LEFT:
            return "flex-start";
        case AlignTypes.CENTER:
            return "center";
        case AlignTypes.RIGHT:
            return "flex-end";
        default:
            return "center";
    }
}};

  background-color: ${({ backgroundColor }) => backgroundColor};
  color: ${({ textColor }) => textColor};
  padding: ${({ padding }) => padding};
  margin: ${({ margin }) => margin};
  width: ${({ width }) => width};
  height: ${({ height }) => height};
  cursor: ${({ cursor }) => cursor};

  outline: ${({ outline }) => (outline ? outline : "none")};
  border: ${({ border }) => (border ? border : "none")};
  border-radius: ${({ borderRadius }) => (borderRadius ? borderRadius : "0")};
`;
export const Label = styled.label `
  background-color: ${({ backgroundColor }) => backgroundColor};
  color: ${({ textColor }) => textColor};
`;
export const InputWrapper = styled.div `
  display: flex;
  justify-content: center;
  align-items: center;
  width: 100%;
`;
export const InputField = styled.input `
  padding: ${({ padding }) => padding};
  margin: ${({ margin }) => margin};
  width: ${({ type }) => [InputTypes.CHECKBOX, InputTypes.RADIO].includes(type) ? "auto" : "100%"};
  height: 100%;
  align-self: center;
  background-color: transparent;

  ${(props) => {
    switch (props.type) {
        case InputTypes.TEXT: {
            return `
          border: none;
          border-bottom: 1px solid ${DEFAULT_PRIMARY};
          outline: none;
        `;
        }
        case InputTypes.PASSWORD: {
            return `
          border: none;
          border-bottom: 1px solid ${DEFAULT_PRIMARY};
          outline: none;
        `;
        }
        case InputTypes.NUMBER: {
            return `
          border: none;
          border-bottom: 1px solid ${DEFAULT_PRIMARY};
          outline: none;
        `;
        }
        case InputTypes.EMAIL: {
            return `
          border: none;
          border-bottom: 1px solid ${DEFAULT_PRIMARY};
          outline: none;
        `;
        }
        case InputTypes.CHECKBOX: {
            const checkboxProps = props;
            return `
        ${checkboxProps.icon && "display: none"};
        & + .checkbox-checked-image {
          display: inline-block;
          width: ${checkboxProps.iconSize};
          height: ${checkboxProps.iconSize};
          background: transparent;
          margin-right: 10px;
          border: 1px solid ${DEFAULT_PRIMARY};
        }
        &:checked + .checkbox-checked-image {
          background: url('${checkboxProps.icon}') no-repeat center center;
        }`;
        }
        case InputTypes.RADIO: {
            return ``;
        }
        case InputTypes.HIDDEN: {
            return ``;
        }
    }
}}
`;
export const Error = styled.span `
  background-color: ${({ backgroundColor }) => backgroundColor};
  color: ${({ textColor }) => textColor};
`;
//# sourceMappingURL=styles.js.map