import { AlignTypes } from "../../../types/alignTypes";
import { InputTypes } from "./inputTypes";
export interface InputProps {
    className?: string;
    id?: string;
    name?: string;
    type?: InputTypes;
    labelText?: string;
    placeholder?: string;
    icon?: string;
    iconSize?: string;
    withShowHide?: boolean;
    value?: string | number;
    backgroundColor?: string;
    textColor?: string;
    labelBackgroundColor?: string;
    labelTextColor?: string;
    containerPadding?: string;
    containerMargin?: string;
    padding?: string;
    margin?: string;
    width?: string;
    height?: string;
    outline?: string;
    border?: string;
    borderRadius?: string;
    cursor?: string;
    required?: boolean;
    min?: number;
    max?: number;
    autoFocus?: boolean;
    checked?: boolean;
    disabled?: boolean;
    maxLength?: number;
    minLength?: number;
    pattern?: string;
    step?: number;
    error?: string;
    errorBackgroundColor?: string;
    errorTextColor?: string;
    alignItem?: AlignTypes;
    onChange?: (...args: any) => void;
    onFocus?: (...args: any) => void;
    onBlur?: (...args: any) => void;
}
export interface BaseInputProps {
    className?: string;
    name?: string;
    id?: string;
    type: InputTypes;
    value?: string | number;
    padding?: string;
    margin?: string;
    required?: boolean;
    autoFocus?: boolean;
    disabled?: boolean;
    onChange?: (...args: any) => void;
    onFocus?: (...args: any) => void;
    onBlur?: (...args: any) => void;
}
export interface TextInputProps extends BaseInputProps {
    placeholder?: string;
    icon?: string;
    iconSize?: string;
    maxLength?: number;
    minLength?: number;
    pattern?: string;
}
export interface NumberInputProps extends BaseInputProps {
    placeholder?: string;
    icon?: string;
    iconSize?: string;
    min?: number;
    max?: number;
    step?: number;
}
export interface PasswordInputProps extends BaseInputProps {
    placeholder?: string;
    icon?: string;
    iconSize?: string;
    withShowHide?: boolean;
    maxLength?: number;
    minLength?: number;
    pattern?: string;
}
export interface EmailInputProps extends BaseInputProps {
    placeholder?: string;
    icon?: string;
    iconSize?: string;
    maxLength?: number;
    minLength?: number;
    pattern?: string;
}
export interface CheckboxInputProps extends BaseInputProps {
    icon?: string;
    iconSize?: string;
    checked?: boolean;
}
export declare type HiddenInputProps = BaseInputProps;
export interface RadioInputProps extends BaseInputProps {
    checked?: boolean;
}
export declare type InputType = TextInputProps | PasswordInputProps | NumberInputProps | EmailInputProps | CheckboxInputProps | HiddenInputProps | RadioInputProps;
